@@ -46,8 +46,12 @@ class Tracker:
         """Add a new event to the database."""
         read = self._db_handler.read_events()
 
-        number_rows = read.shape[0]-1 
-        past_task = str(read.iloc[number_rows]['end_time'])
+        number_rows = read.shape[0]
+        if number_rows == 0:
+            past_task = "no entries"
+        else:
+            number_rows = read.shape[0]-1 
+            past_task = str(read.iloc[number_rows]['end_time'])
         #print(str(past_task))
 
         if past_task == "NaT":
